@@ -2,8 +2,9 @@ from .base import base
 
 
 class articles(base):
-    def __init__(self, token):
-        super().__init__(token)
+
+    def __init__(self, token, domain=True, safe=False, app_secret=None):
+        super().__init__(token, domain, safe, app_secret)
 
     def getById(self, articleId):
         api_name = "contmgn/getArticleById"
