@@ -34,6 +34,8 @@ def request_accesstoken(acc: str, pwd: str, safe=False, domain=True, **kwargs) -
         return accessToken
 
 # domain为真时-取bms。
+
+
 def request_accesstoken_pc(acc: str, pwd: str, safe=False, domain=True, **kwargs) -> str:
     # 请求accesstooke函数
     protocol = "https" if safe else "http"
@@ -50,20 +52,15 @@ def request_accesstoken_pc(acc: str, pwd: str, safe=False, domain=True, **kwargs
 
 
 class base:
-    def __init__(self, token, app_secret=None):
-        """[summary]
-
-        Args:
-            token ([type]): [description]
-            app_secret ([type], optional): [description]. Defaults to None.
-            # domain为真时-取bms。
-        """
+    def __init__(self, token, domain=True, safe=False, app_secret=None):
         self.token = token
+        self.domain = domain
+        self.safe = safe
         self.app_secret = app_secret
 
-    def request(self, api_name=None, method="GET", url=None, api_prefix="api/", safe=False, domain=True, **kwargs):
-        protocol = "https" if safe else "http"
-        domain_name = "bms.chaojidaogou.com" if domain else "it.xxynet.com"
+    def request(self, api_name=None, method="GET", url=None, api_prefix="api/", **kwargs):
+        protocol = "https" if self.safe else "http"
+        domain_name = "bms.chaojidaogou.com" if self.domain else "it.xxynet.com"
         host_name = f"{protocol}://{domain_name}/shopguide/"
         if not url:
             url = f"{host_name}{api_prefix}{api_name}"
@@ -93,19 +90,15 @@ class base:
 
 
 class baseNoapi:
-    def __init__(self, token, app_secret=None):
-        """[summary]
-
-        Args:
-            token ([type]): [description]
-            app_secret ([type], optional): [description]. Defaults to None.
-        """
+    def __init__(self, token, domain=True, safe=False, app_secret=None):
         self.token = token
+        self.domain = domain
+        self.safe = safe
         self.app_secret = app_secret
 
-    def request(self, api_name=None, method="GET", url=None, safe=False, domain=True, **kwargs):
-        protocol = "https" if safe else "http"
-        domain_name = "bms.chaojidaogou.com" if domain else "it.xxynet.com"
+    def request(self, api_name=None, method="GET", url=None, **kwargs):
+        protocol = "https" if self.safe else "http"
+        domain_name = "bms.chaojidaogou.com" if self.domain else "it.xxynet.com"
         host_name = f"{protocol}://{domain_name}/shopguide/"
         if not url:
             url = f"{host_name}{api_name}"
@@ -135,24 +128,20 @@ class baseNoapi:
 
 
 class baseT:
-    def __init__(self, token, app_secret=None):
-        """[summary]
-
-        Args:
-            token ([type]): [description]
-            app_secret ([type], optional): [description]. Defaults to None.
-            这个base 解决 域名不一致的问题， 直接取域名。
-        """
+    def __init__(self, token, domain=True, safe=False, convert=False, app_secret=None):
         self.token = token
+        self.domain = domain
+        self.safe = safe
+        self.convert = convert
         self.app_secret = app_secret
 
-    def request(self, api_name=None, method="GET", url=None, api_prefix="api/", safe=False, domain=True, convert=False, **kwargs):
-        protocol = "https" if safe else "http"
-        domain_name = "bms.chaojidaogou.com" if domain else "it.xxynet.com"
+    def request(self, api_name=None, method="GET", url=None, api_prefix="api/", **kwargs):
+        protocol = "https" if self.safe else "http"
+        domain_name = "bms.chaojidaogou.com" if self.safe else "it.xxynet.com"
         host_name = f"{protocol}://{domain_name}/"
         if not url:
             # url is None:generate url use hostname+api_prefix+apiname
-            url = f"{host_name}{api_prefix}{api_name}" if convert else f"{host_name}{api_name}"
+            url = f"{host_name}{api_prefix}{api_name}" if self.convert else f"{host_name}{api_name}"
         # params
         params = kwargs.get("params", {})
         params["accessToken"] = self.token
@@ -179,24 +168,20 @@ class baseT:
 
 
 class baseSub:
-    def __init__(self, token, app_secret=None):
-        """[summary]
-
-        Args:
-            token ([type]): [description]
-            app_secret ([type], optional): [description]. Defaults to None.
-            这个base 解决 域名不一致的问题， 直接取域名。
-        """
+    def __init__(self, token, domain=True, safe=False, convert=False, app_secret=None):
         self.token = token
+        self.domain = domain
+        self.safe = safe
+        self.convert = convert
         self.app_secret = app_secret
 
-    def request(self, api_name=None, method="GET", url=None, api_prefix="api/", safe=False, domain=True, convert=False, **kwargs):
-        protocol = "https" if safe else "http"
-        domain_name = "sub.chaojidaogou.com" if domain else "it.xxynet.com"
+    def request(self, api_name=None, method="GET", url=None, api_prefix="api/",  **kwargs):
+        protocol = "https" if self.safe else "http"
+        domain_name = "sub.chaojidaogou.com" if self.domain else "it.xxynet.com"
         host_name = f"{protocol}://{domain_name}/"
         if not url:
             # url is None:generate url use hostname+api_prefix+apiname
-            url = f"{host_name}{api_prefix}{api_name}" if convert else f"{host_name}{api_name}"
+            url = f"{host_name}{api_prefix}{api_name}" if self.convert else f"{host_name}{api_name}"
         # params
         params = kwargs.get("params", {})
         params["accessToken"] = self.token
@@ -223,20 +208,15 @@ class baseSub:
 
 
 class baseCient:
-    def __init__(self, token, app_secret=None):
-        """[summary]
-
-        Args:
-            token ([type]): [description]
-            app_secret ([type], optional): [description]. Defaults to None.
-            这个base 解决 域名不一致的问题， 直接取域名。
-        """
+    def __init__(self, token, domain=True, safe=False, app_secret=None):
         self.token = token
+        self.domain = domain
+        self.safe = safe
         self.app_secret = app_secret
 
-    def request(self, api_name=None, method="GET", url=None, api_prefix="api/", safe=False, domain=True, **kwargs):
-        protocol = "https" if safe else "http"
-        domain_name = "cient.chaojidaogou.com" if domain else "it.xxynet.com"
+    def request(self, api_name=None, method="GET", url=None, api_prefix="api/", **kwargs):
+        protocol = "https" if self.safe else "http"
+        domain_name = "cient.chaojidaogou.com" if self.domain else "it.xxynet.com"
         host_name = f"{protocol}://{domain_name}/"
         if not url:
             # url is None:generate url use hostname+api_prefix+apiname
@@ -267,20 +247,15 @@ class baseCient:
 
 
 class baseApi:
-    def __init__(self, token, app_secret=None):
-        """[summary]
-
-        Args:
-            token ([type]): [description]
-            app_secret ([type], optional): [description]. Defaults to None.
-            这个base 解决 域名不一致的问题， 直接取域名。
-        """
+    def __init__(self, token, domain=True, safe=False, app_secret=None):
         self.token = token
+        self.domain = domain
+        self.safe = safe
         self.app_secret = app_secret
 
-    def request(self, api_name=None, method="GET", url=None, api_prefix="api/", safe=False, domain=True, **kwargs):
-        protocol = "https" if safe else "http"
-        domain_name = "api.chaojidaogou.com" if domain else "it.xxynet.com"
+    def request(self, api_name=None, method="GET", url=None, api_prefix="api/", **kwargs):
+        protocol = "https" if self.safe else "http"
+        domain_name = "api.chaojidaogou.com" if self.domain else "it.xxynet.com"
         host_name = f"{protocol}://{domain_name}/"
         if not url:
             # url is None:generate url use hostname+api_prefix+apiname
@@ -310,23 +285,14 @@ class baseApi:
         return response_raw
 
 
-
-
-
 class baseApixxYent:
-    def __init__(self, token, app_secret=None):
-        """[summary]
-
-        Args:
-            token ([type]): [description]
-            app_secret ([type], optional): [description]. Defaults to None.
-            这个base 解决 域名不一致的问题， 直接取域名。
-        """
+    def __init__(self, token, domain=True,  app_secret=None):
         self.token = token
+        self.domain = domain
         self.app_secret = app_secret
 
-    def request(self, api_name=None, method="GET", url=None,domain=True, **kwargs):
-        domain_name = "api.xxynet.com" if domain else "it.xxynet.com"
+    def request(self, api_name=None, method="GET", url=None, **kwargs):
+        domain_name = "api.xxynet.com" if self.domain else "it.xxynet.com"
         host_name = f"https://{domain_name}/"
         if not url:
             # url is None:generate url use hostname+api_prefix+apiname
