@@ -3,8 +3,9 @@ from .base import base
 
 
 class dollyin(base):
-    def __init__(self, token):
-        super().__init__(token)
+        
+    def __init__(self, token, domain=True, safe=False, app_secret=None):
+        super().__init__(token, domain, safe, app_secret)
         self.lecturer_id = self.get_user_id()
 
     def get_user_info(self):
