@@ -3,8 +3,9 @@ from .base import base
 
 
 class bbs(base):
-    def __init__(self, token):
-        super().__init__(token)
+
+    def __init__(self, token, domain=True, safe=False, app_secret=None):
+        super().__init__(token, domain, safe, app_secret)
 
     def getTag(self):
         api_name = "bbs/getTagList"
