@@ -2,8 +2,10 @@ from .base import base
 
 
 class globalSearch(base):
-    def __init__(self, token):
-        super().__init__(token)
+
+    def __init__(self, token, domain=True, safe=False, app_secret=None):
+        super().__init__(token, domain, safe, app_secret)
+
 
     def activity(self, keyWord, page=1):
         api_name = "globalSearchActivity"
