@@ -2,8 +2,9 @@ from .base import base
 
 
 class lear_path(base):
-    def __init__(self, token):
-        super().__init__(token)
+
+    def __init__(self, token, domain=True, safe=False, app_secret=None):
+        super().__init__(token, domain, safe, app_secret)
 
     def getTopicList(self, activityId, order=1, onlyShowImg=0, page=1, rows=20):
         api_name = "activity/getTopicList"
