@@ -13,8 +13,8 @@ class appMod(base):
     app模块管理
     """
 
-    def __init__(self, token) -> None:
-        super().__init__(token)
+    def __init__(self, token, domain=True, safe=False, app_secret=None):
+        super().__init__(token, domain, safe, app_secret)
 
     def request(self, **kwarg):
         api_prefix = ""
@@ -116,9 +116,8 @@ class appModCat(base):
     """
     模块分类管理
     """
-
-    def __init__(self, token) -> None:
-        super().__init__(token)
+    def __init__(self, token, domain=True, safe=False, app_secret=None):
+        super().__init__(token, domain, safe, app_secret)
 
     def request(self, **kwarg):
         api_prefix = ""
