@@ -11,19 +11,18 @@ from cjdg_open_api.base import baseApixxYent
 
 
 class paltFrom(baseApixxYent):
-    def __init__(self, token, app_secret=None):
-        super().__init__(token, app_secret)
-
+    def __init__(self, token, domain=True, safe=False, app_secret=None):
+        super().__init__(token, domain, safe, app_secret)
 
 # 周榜,月榜（0 or 1的区别）
 
     def getCycleList(self, data):
         api_name = "enter/superguide/platformRanking/userLearningLength/getCycleList"
-        return self.request(api_name=api_name, json=data,method="POST")
+        return self.request(api_name=api_name, json=data, method="POST")
 
     def findRanking(self, data):
         api_name = "enter/superguide/platformRanking/userLearningLength/findRanking"
-        return self.request(api_name=api_name, json=data,method="POST")
+        return self.request(api_name=api_name, json=data, method="POST")
 
 
 def main():
