@@ -4,8 +4,9 @@ from .base import base
 
 
 class pk(base):
-    def __init__(self, token):
-        super().__init__(token)
+
+    def __init__(self, token, domain=True, safe=False, app_secret=None):
+        super().__init__(token, domain, safe, app_secret)
 
 
     # 排行榜PK列表
