@@ -4,8 +4,8 @@ from .base import base
 
 class user(base):
 
-    def __init__(self, token, app_secret=None):
-        super().__init__(token, app_secret)
+    def __init__(self, token, domain=True, safe=False, app_secret=None):
+        super().__init__(token, domain, safe, app_secret)
 
 # 查询用户
     def list(self,data):
