@@ -12,7 +12,7 @@ from loguru import logger
 
 def request_accesstoken(acc: str, pwd: str, safe=False, domain=True, **kwargs) -> str:
     # 请求accesstooke函数
-    protocol = "https" if safe else "http"
+    protocol = "https" if self.safe else "http"
     domain_name = "bms.chaojidaogou.com" if domain else "it.xxynet.com"
     url = f"{protocol}://{domain_name}/shopguide/api/auth/logonweb"
     data = {}
@@ -27,21 +27,23 @@ def request_accesstoken(acc: str, pwd: str, safe=False, domain=True, **kwargs) -
 
 
 class base:
-    def __init__(self, token, app_secret=None):
+    def __init__(self, token, domain=True, safe=False, app_secret=None):
         self.token = token
+        self.domain = domain
+        self.safe = safe
         self.app_secret = app_secret
 
-    def request(self, api_name=None, params={}, data={}, json={}, headers={}, method="GET", url=None, safe=False, domain=True, **kwargs):
+    def request(self, api_name=None, params={}, data={}, json={}, headers={}, method="GET", url=None, **kwargs):
 
-        protocol = "https" if safe else "http"
-        domain_name = "bms.chaojidaogou.com" if domain else "it.xxynet.com"
+        protocol = "https" if self.safe else "http"
+        domain_name = "bms.chaojidaogou.com" if self.domain else "it.xxynet.com"
         host_name = f"{protocol}://{domain_name}/shopguide/api/"
         if not url:
             if host_name not in api_name:
                 url = f"{host_name}{api_name}"
+                logger.debug(url)
 
         condition = {}
-
         if "accessToken" not in params:
             # 没有token自动添加
             params["accessToken"] = self.token
@@ -71,14 +73,16 @@ class base:
 
 
 class baseApi:
-    def __init__(self, token, app_secret=None):
+    def __init__(self, token, domain=True, safe=False, app_secret=None):
         self.token = token
+        self.domain = domain
+        self.safe = safe
         self.app_secret = app_secret
 
-    def request(self, api_name=None, params={}, data={}, json={}, headers={}, method="GET", url=None, safe=False, domain=True, **kwargs):
+    def request(self, api_name=None, params={}, data={}, json={}, headers={}, method="GET", url=None, **kwargs):
 
-        protocol = "https" if safe else "http"
-        domain_name = "api.chaojidaogou.com" if domain else "it.xxynet.com"
+        protocol = "https" if self.safe else "http"
+        domain_name = "api.chaojidaogou.com" if self.domain else "it.xxynet.com"
         host_name = f"{protocol}://{domain_name}/shopguide/api/"
         if not url:
             if host_name not in api_name:
@@ -114,14 +118,17 @@ class baseApi:
 
 
 class baseSub:
-    def __init__(self, token, app_secret=None):
+    def __init__(self, token, domain=True, safe=False, app_secret=None):
         self.token = token
+        self.domain = domain
+        self.safe = safe
         self.app_secret = app_secret
 
-    def request(self, api_name=None, params={}, data={}, json={}, headers={}, method="GET", url=None, safe=False, domain=True, **kwargs):
 
-        protocol = "https" if safe else "http"
-        domain_name = "sub.chaojidaogou.com" if domain else "it.xxynet.com"
+    def request(self, api_name=None, params={}, data={}, json={}, headers={}, method="GET", url=None,**kwargs):
+
+        protocol = "https" if self.safe else "http"
+        domain_name = "sub.chaojidaogou.com" if self.domain else "it.xxynet.com"
         host_name = f"{protocol}://{domain_name}/shopguide/api/"
         if not url:
             if host_name not in api_name:
@@ -157,14 +164,16 @@ class baseSub:
 
 
 class baseCient:
-    def __init__(self, token, app_secret=None):
+    def __init__(self, token, domain=True, safe=False, app_secret=None):
         self.token = token
+        self.domain = domain
+        self.safe = safe
         self.app_secret = app_secret
 
-    def request(self, api_name=None, params={}, data={}, json={}, headers={}, method="GET", url=None, safe=False, domain=True, **kwargs):
+    def request(self, api_name=None, params={}, data={}, json={}, headers={}, method="GET", url=None,**kwargs):
 
-        protocol = "https" if safe else "http"
-        domain_name = "cient.chaojidaogou.com" if domain else "it.xxynet.com"
+        protocol = "https" if self.safe else "http"
+        domain_name = "cient.chaojidaogou.com" if self.domain else "it.xxynet.com"
         host_name = f"{protocol}://{domain_name}/shopguide/api/"
         if not url:
             if host_name not in api_name:
@@ -200,13 +209,16 @@ class baseCient:
 
 
 class baseApixxYent:
-    def __init__(self, token, app_secret=None):
+    def __init__(self, token, domain=True, safe=False, app_secret=None):
         self.token = token
+        self.domain = domain
+        self.safe = safe
         self.app_secret = app_secret
 
-    def request(self, api_name=None, params={}, data={}, json={}, headers={}, method="GET", url=None,domain=True, **kwargs):
-        domain_name = "api.xxynet.com" if domain else "it.xxynet.com"
-        host_name = f"https://{domain_name}/"
+    def request(self, api_name=None, params={}, data={}, json={}, headers={}, method="GET", url=None, **kwargs):
+        protocol = "https" if self.safe else "http"
+        domain_name = "api.xxynet.com" if self.domain else "it.xxynet.com"
+        host_name = f"{protocol}://{domain_name}/"
         if not url:
             if host_name not in api_name:
                 url = f"{host_name}{api_name}"
@@ -242,14 +254,16 @@ class baseApixxYent:
 
 
 class baseQuestion:
-    def __init__(self, token, app_secret=None):
+    def __init__(self, token, domain=True, safe=False, app_secret=None):
         self.token = token
+        self.domain = domain
+        self.safe = safe
         self.app_secret = app_secret
 
-    def request(self, api_name=None, params={}, data={}, json={}, headers={}, method="GET", url=None, safe=False, domain=False, **kwargs):
+    def request(self, api_name=None, params={}, data={}, json={}, headers={}, method="GET", url=None, **kwargs):
 
-        protocol = "https" if safe else "http"
-        domain_name = "bms.chaojidaogou.com" if domain else "it.xxynet.com"
+        protocol = "https" if self.safe else "http"
+        domain_name = "bms.chaojidaogou.com" if self.domain else "it.xxynet.com"
         host_name = f"{protocol}://{domain_name}/shopguide-question/api/"
         if not url:
             if host_name not in api_name:
